@@ -1,5 +1,4 @@
 """ Entry point for 802.1X speaker. """
-import random
 from eventlet import sleep, GreenPool
 from eventlet.queue import Queue
 
@@ -16,6 +15,11 @@ from chewie.radius_socket import RadiusSocket
 from chewie.state_machines.eap_state_machine import FullEAPStateMachine
 from chewie.state_machines.mab_state_machine import MacAuthenticationBypassStateMachine
 from chewie.utils import get_logger, MessageParseError, EapQueueMessage
+from chewie.utils import get_random_id as utils_get_random_id
+
+
+def get_random_id():
+    return utils_get_random_id()
 
 
 def unpack_byte_string(byte_string):
@@ -23,9 +27,6 @@ def unpack_byte_string(byte_string):
     return "".join("%02x" % x for x in byte_string)
 
 
-def get_random_id():  # pylint: disable=missing-docstring
-    return random.randint(0, 200)
-
 # TODO set unneeded public methods to private
 # pylint: disable=too-many-instance-attributes
 # pylint: disable=too-many-public-methods
@@ -216,7 +217,7 @@ class Chewie:
             self.logger.debug("executing timer premptive on port %s", port_id)
             self.send_preemptive_identity_request(port_id)
 
-    def send_preemptive_identity_request(self, port_id):
+    def send_preemptive_identity_request(self, port_id, state_machine=None):
         """
         Message (EAP Identity Request) that notifies supplicant that port is using 802.1X
         Args:
@@ -224,11 +225,15 @@ class Chewie:
 
         """
         _id = get_random_id()
+        # ID of preemptive reauth attempt must be different to ID of initial authentication.
+        if state_machine is not None and hasattr(state_machine, 'current_id'):
+            while _id == state_machine.current_id:
+                _id = get_random_id()
         data = IdentityMessage(self.PAE_GROUP_ADDRESS, _id, Eap.REQUEST, "")
         self.port_to_eapol_id[port_id] = _id
         self.eap_output_messages.put_nowait(
             EapQueueMessage(data, self.PAE_GROUP_ADDRESS, MacAddress.from_string(port_id)))
-        self.logger.info("sending premptive on port %s", port_id)
+        self.logger.info("sending premptive on port %s with ID %s", port_id, _id)
 
     def reauth_port(self, src_mac, port_id):
         """
@@ -242,7 +247,7 @@ class Chewie:
 
         if state_machine and state_machine.is_success():
             self.logger.info('reauthenticating src_mac: %s on port: %s', src_mac, port_id)
-            self.send_preemptive_identity_request(port_id)
+            self.send_preemptive_identity_request(port_id, state_machine)
         elif state_machine is None:
             self.logger.debug('not reauthing. state machine on port: %s, mac: %s is none', port_id,
                               src_mac)
